Method: Settingslogic#initialize
- Defined in:
- lib/settingslogic.rb
#initialize(hash_or_file = self.class.source) ⇒ Settingslogic
Initializes a new settings object. You can initialize an object in any of the following ways:
Settings.new(:application) # will look for config/application.yml
Settings.new("application.yaml") # will look for application.yaml
Settings.new("/var/configs/application.yml") # will look for /var/configs/application.yml
Settings.new(:config1 => 1, :config2 => 2)
Basically if you pass a symbol it will look for that file in the configs directory of your rails app, if you are using this in rails. If you pass a string it should be an absolute path to your settings file. Then you can pass a hash, and it just allows you to access the hash via methods.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/settingslogic.rb', line 46 def initialize(hash_or_file = self.class.source) case hash_or_file when Hash self.update hash_or_file else hash = YAML.load(ERB.new(File.read(hash_or_file)).result).to_hash hash = hash[self.class.namespace] if self.class.namespace self.update hash end end |